From 9bdb95c9e34cef640534e5e5a1e2225a80442000 Mon Sep 17 00:00:00 2001
From: HelenHuang <LinHuang@pollex.com.tw>
Date: 星期四, 09 六月 2022 15:48:15 +0800
Subject: [PATCH] TODO#139894 [ footer -最下方說明與保經代合作 ] 文案修改

---
 PAMapp/node_modules/istanbul-lib-instrument/src/instrumenter.js |    6 ++++--
 1 files changed, 4 insertions(+), 2 deletions(-)

diff --git a/PAMapp/node_modules/istanbul-lib-instrument/src/instrumenter.js b/PAMapp/node_modules/istanbul-lib-instrument/src/instrumenter.js
index f051954..95743c7 100644
--- a/PAMapp/node_modules/istanbul-lib-instrument/src/instrumenter.js
+++ b/PAMapp/node_modules/istanbul-lib-instrument/src/instrumenter.js
@@ -14,7 +14,8 @@
  * instead.
  * @param {Object} opts optional.
  * @param {string} [opts.coverageVariable=__coverage__] name of global coverage variable.
  * @param {boolean} [opts.preserveComments=false] preserve comments in output
  * @param {boolean} [opts.compact=true] generate compact code.
  * @param {boolean} [opts.esModules=false] set to true to instrument ES6 modules.
  * @param {boolean} [opts.autoWrap=false] set to true to allow `return` statements outside of functions.
@@ -22,7 +23,7 @@
  * @param {Array} [opts.ignoreClassMethods=[]] set to array of class method names to ignore for coverage.
  * @param {Function} [opts.sourceMapUrlCallback=null] a callback function that is called when a source map URL
  *     is found in the original code. This function is called with the source file name and the source map URL.
- * @param {boolean} [opts.debug=false] - turn debugging on
+ * @param {boolean} [opts.debug=false] - turn debugging on.
  * @param {array} [opts.parserPlugins] - set babel parser plugins, see @istanbuljs/schema for defaults.
  */
 class Instrumenter {
@@ -73,6 +74,7 @@
                     ({ types }) => {
                         const ee = programVisitor(types, filename, {
                             coverageVariable: opts.coverageVariable,
+                            reportLogic: opts.reportLogic,
                             coverageGlobalScope: opts.coverageGlobalScope,
                             coverageGlobalScopeFunc:
                                 opts.coverageGlobalScopeFunc,
@@ -14,7 +14,8 @@
  * @param {Object} opts optional.
  * @param {string} [opts.coverageVariable=__coverage__] name of global coverage variable.
- * @param {boolean} [opts.preserveComments=false] preserve comments in output
+ * @param {boolean} [opts.reportLogic=false] report boolean value of logical expressions.
+ * @param {boolean} [opts.preserveComments=false] preserve comments in output.
  * @param {boolean} [opts.compact=true] generate compact code.
  * @param {boolean} [opts.esModules=false] set to true to instrument ES6 modules.

--
Gitblit v1.8.0